(get-client)Access the dynamic client variable. Supports treating client as an IDeref or a literal value. The result of this function is what all openai services will use
Access the dynamic *client* variable. Supports treating *client* as an IDeref or a literal value. The result of this function is what all openai services will use
(get-client-async)Access the dynamic client variable. Supports treating client as an IDeref or a literal value. The result of this function is what all openai services will use
Access the dynamic *client* variable. Supports treating *client* as an IDeref or a literal value. The result of this function is what all openai services will use
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |